Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| PGL DISTRIBUICAO DE ALIMENTOS LTDA
CNPJ: 87.397.865/0021-65 Inscrição Estadual: 1090357122
Evandro Behr - RS 509 KM 08, 6645, CAMOBI, Santa Maria, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 91069 Série: 205 Data de Emissão: 01/10/2019 11:09:34
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1087 3978 6500 2165 6520 5000 0910 6910 0217 8969
Protocolo de Autorização: 143191343042667
CONSUMIDOR
Consumidor não identificado
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
434590 | PADARIA - PAO FRANCES PERUZZO KG | 0,428 | KG | 7,69 | 3,29
686600 | AGUA COCO DEL VALLE 1L | 1 | UN | 11,49 | 11,49
291500 | AGUA COCO KERO COCO 1L | 1 | UN | 9,35 | 9,35
123620030 | GELATINA DR OETKER DIET 12G. LIMAO | 1 | UN | 2,89 | 2,89
123620010 | GELATINA DR OETKER DIET ABACAXI 12G | 1 | UN | 2,89 | 2,89
659070 | GELATINA DR OETKER GRANBMIRTBER 12G | 1 | UN | 2,89 | 2,89
158900010 | MASSA SEMOLA ISABELA BOM G 500G. PARAF | 1 | UN | 1,99 | 1,99
413680 | SABONETEIRA MARCO BONI UN | 1 | UN | 5,99 | 5,99
690480 | RODO PLAST P PIA ESFREBOM | 1 | UN | 9,29 | 9,29
Valor total R$ | 50,07
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:41